// ウォーターマークのあるファイルのパスを指定する.
const WATERMARK_FILE_PATH = "C:\\Users\\HogeHoge\\Watermark.png"
// 元画像の長編に対するウォーターマーク画像の横幅の割合を指定する.
const SIZE_RATIO = 0.1;
// ウォーターマークの横位置 (LEFT / CENTER / RIGHT) を指定する.
const POSITION_X = "CENTER";
// ウォーターマークの縦位置 (TOP / CENTER / BOTTOM) を指定する.
const POSITION_Y = "CENTER";
// ウォーターマークの端と元画像の端の間のマージンを元画像の横幅との割合で指定する.
// ※ 横位置を CENTER 以外に指定しているときに作用する.
const MARGIN_X = 0.02;
// ウォーターマークの端と元画像の端の間のマージンを元画像の縦幅との割合でしているする.
// ※ 縦位置を CENTER 以外に指定しているときに作用する.
const MARGIN_Y = 0.02;
// ウォーターマークの不透明度をパーセンテージで指定する.
const OPACITY = 80;

// 元のファイルの情報を保持する
var masterDoc = activeDocument;
var masterWidth = activeDocument.width;
var masterHeight = activeDocument.height;
var originalPreferencesRulerUnits = preferences.rulerUnits;

// ピクセルで計算するので尺度を変更する。
preferences.rulerUnits = Units.PIXELS;

// ウォーターマークのファイルを開く
fileObj = new File(WATERMARK_FILE_PATH);
app.open(fileObj);

// ウォーターマークの拡縮割合を算出しリサイズする
if (masterWidth > masterHeight) {
  var imageRatio = masterWidth * SIZE_RATIO / activeDocument.width;
} else {
  var imageRatio = masterHeight * SIZE_RATIO / activeDocument.width;
}
activeDocument.resizeImage(activeDocument.width * imageRatio, activeDocument.height * imageRatio);

// 元画像にウォーターマークを追加する
activeDocument.activeLayer.copy();
activeDocument.close(SaveOptions.DONOTSAVECHANGES);
var wmLayObj = activeDocument.artLayers.add();
masterDoc.paste();

// レイヤーサイズを適正化
wmLayObj.resize = (activeDocument.width * imageRatio, activeDocument.height * imageRatio);

// レイヤーの位置を変更する
// 移動は絶対位置ではなく現在の位置からの相対位置をしているため、移動距離の算出
var translateX = 0;
var translateY = 0;
wmBounds = activeDocument.activeLayer.bounds;

// 横の移動距離の算出
if (POSITION_X == "CENTER") {
  translateX = (masterWidth / 2 - (parseInt(wmBounds[2]) - (parseInt(wmBounds[2]) - parseInt(wmBounds[0])) / 2 ));
} else if (POSITION_X == "LEFT"){
  translateX = (masterWidth * MARGIN_X) - parseInt(wmBounds[0]);
} else if (POSITION_X == "RIGHT") {
  translateX =  (masterWidth - masterWidth * MARGIN_X) - parseInt(wmBounds[2]);
}

// 縦の移動距離の算出
if (POSITION_Y == "CENTER") {
  translateY = (masterHeight / 2 - (parseInt(wmBounds[3]) - (parseInt(wmBounds[3]) - parseInt(wmBounds[1])) / 2 ));
} else if (POSITION_Y == "TOP"){
  translateY = (masterHeight * MARGIN_Y) - parseInt(wmBounds[1]);
} else if (POSITION_Y == "BOTTOM") {
  translateY =  (masterHeight - masterHeight * MARGIN_Y) - parseInt(wmBounds[3]);
}

// 実際の移動処理
wmLayObj.translate(translateX, translateY);

// 不透明度の変更
wmLayObj.opacity = OPACITY;

preferences.rulerUnits = originalPreferencesRulerUnits;
